@@ -1,9 +1,9 @@
 <?php
 /*
- * @version $Id: solutiontype.php 22656 2014-02-12 16:15:25Z moyo $
+ * @version $Id: solutiontype.php 17152 2012-01-24 11:22:16Z moyo $
  -------------------------------------------------------------------------
  GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2014 by the INDEPNET Development Team.
+ Copyright (C) 2003-2012 by the INDEPNET Development Team.
 
  http://indepnet.net/   http://glpi-project.org
  -------------------------------------------------------------------------
@@ -27,11 +27,14 @@
  --------------------------------------------------------------------------
  */
 
-/** @file
-* @brief
-*/
+// ----------------------------------------------------------------------
+// Original Author of file: Remi collet
+// Purpose of file:
+// ----------------------------------------------------------------------
 
-include ('../inc/includes.php');
+
+define('GLPI_ROOT', '..');
+include (GLPI_ROOT . "/inc/includes.php");
 
 $dropdown = new SolutionType();
 include (GLPI_ROOT . "/front/dropdown.common.php");
